@@ -1,12 +1,18 @@
 package Date::Holidays::GB::EAW;
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.007'; our $VERSION = '0.008'; # VERSION
 
 use strict;
 use warnings;
 
 use Date::Holidays::GB;
 
+use base qw( Exporter );
+our @EXPORT_OK = qw(
+  holidays
+  is_holiday
+);
+
 sub holidays {
     my %args
         = $_[0] =~ m/\D/
